.. _cli-show-version:

============================
``wwtdatatool show version``
============================

The ``show version`` command prints out the current version of the ``wwt_data_formats``
software package.

.. _DOI: https://help.zenodo.org/

Usage
=====

.. code-block:: shell

   wwtdatatool show version

Prints out the current version of ``wwt_data_formats``.

Notes
=====

In academic contexts, you may also wish to use the :ref:`cli-show-version-doi`
command to obtain a `DOI`_ that can be used to properly cite your use of the
``wwt_data_formats`` software.

.. _DOI: https://help.zenodo.org/


See Also
========

- :ref:`cli-show-version-doi`
